using System;
using System.Collections;
using System.ComponentModel;
using System.Data;
using System.Drawing;
using System.Web;
using System.Web.SessionState;
using System.Web.UI;
using System.Web.UI.WebControls;
using System.Web.UI.HtmlControls;
using Dell.GDCBR.FATCAT.Resources;   

/*****************************************************************
File            : GenericReportPresentation.aspx.cs
Module/Component: Dell.GDCBR.ICat.Presentation
Assembly        : ICAT.PresentationLogic
Remarks         : 
Classes         : ReportTest
Created Date    : 12/13/2004
Revisions       : Fabiano Pereira
                : 01/05/2005 - Fabiano Pereira da Rosa
                  - CR#06
                    Create another method to pass an arraylist object
                    to export several datagrids to an excel file.
                : 02/01/2005 - Luciana Mesquita Belleza
                  - UC 2.10 Export Report to Excel                       
                    new method WriteHtmlHeader,
                    new method WriteHtmlFoot 
                :  05/29/2005 - Fabiano Pereira
                   IMT2 - I2 - Defect #234 - Added Decode method.                      
*****************************************************************/


namespace Dell.GDCBR.FATCAT.Presentation
{
  /// <summary>
  /// Summary description for ReportTest.
  /// </summary>
  public class GenericReportPresentation : FATCATBaseController
  {
    protected string pReportName;
    protected FATCATReportInfo pReportInfo = null; 
    
    public GenericReportPresentation()
    {
      this.pAuthRequired = false;
    }

    protected override void PageLoadEvent(object sender, System.EventArgs e)
    {
      base.PageLoadEvent(sender, e);
    }

    /// <summary>
    /// Export data within a table object to an excel file. 
    /// </summary>
    /// <param name="mGrid">Table containing data to be printed.</param>
    protected void ExportToExcel(string mHtmlContent)
    {
      Response.Clear();
      Response.Buffer= false;
      Response.ContentType = "application/vnd.ms-excel";
      Response.Charset = "";
      this.EnableViewState = false;

      try
      {
		    WriteHtmlHeader();		    
        System.IO.StringWriter lStringWriter = new System.IO.StringWriter();
        System.Web.UI.HtmlTextWriter lHtmlTextWriter = new System.Web.UI.HtmlTextWriter(lStringWriter);
        Response.Write("<BR>");
        Response.Write ("Report Name: " + this.pReportName);
        Response.Write("<BR>");
        Response.Write ("Print date: " + DateTime.Now.ToShortDateString());
        Response.Write("<BR>");
        Response.Write("<BR>");
        Response.Write(mHtmlContent);

	      Response.Write(lStringWriter.ToString());
		    WriteHtmlFoot();
      }
      catch(Exception)
      {
        Response.Write("Error while exporting to excel.");
      }
      Response.End();
    }
    
    /// <summary>
    /// Export data within the datagrid to an excel file. 
    /// </summary>
    /// <param name="mGrid">Datagrid containing data to be printed.</param>
    protected void ExportToExcel(DataGrid mGrid)
    {
      if (mGrid.Items.Count == 0)
      {
        Response.Write("<script>alert('No results to export.');</script>");
        //Prevents open a new page in the history every time the alert is fired.
        //Thus, when an alert is fired, it backs to the calling page. 
        Response.Write("<script>history.go(-1);</script>");
        return;
      }
      
      Response.Clear();
      Response.Buffer= false;
      Response.ContentType = "application/vnd.ms-excel";
      Response.Charset = "";
      this.EnableViewState = false;

      try
      {
		    WriteHtmlHeader();		        		    
        System.IO.StringWriter lStringWriter = new System.IO.StringWriter();
        System.Web.UI.HtmlTextWriter lHtmlTextWriter = new System.Web.UI.HtmlTextWriter(lStringWriter);
        Response.Write("<BR>");
        Response.Write ("Report Name: " + this.pReportName);
        Response.Write("<BR>");
        Response.Write ("Print date: " + DateTime.Now.ToShortDateString());
        Response.Write("<BR>");
        Response.Write("<BR>");

        mGrid.RenderControl(lHtmlTextWriter);
        
        Response.Write(lStringWriter.ToString());
		    WriteHtmlFoot();
      }
      catch(Exception)
      {
        Response.Write("Error while exporting to excel.");
      }

      Response.End();
    }

    /// <summary>
    /// Export a collection of datagrids to an excel file.
    /// </summary>
    /// <param name="mDataGridList">A arraylist object containing datagrids.</param>
    protected void ExportToExcel(ArrayList mDataGridList)
    {
      //Scope
      int lCount = 0;

      foreach(DataGrid Grid in mDataGridList)
      {
        if (Grid.Items.Count == 0)
        {
          lCount++;
        }

        if (lCount == mDataGridList.Count)
        {
          Response.Write("<script>alert('No results to export.')</script>");
          return;
        }
      }
      
      Response.Clear();
      Response.Buffer= false;
      Response.ContentType = "application/vnd.ms-excel";
      Response.Charset = "";
      this.EnableViewState = false;

      try
      {
		    WriteHtmlHeader();                
        System.IO.StringWriter lStringWriter = new System.IO.StringWriter();
        System.Web.UI.HtmlTextWriter lHtmlTextWriter = new System.Web.UI.HtmlTextWriter(lStringWriter);
        Response.Write("<BR>");
        Response.Write ("Report Name: " + this.pReportName);
        Response.Write("<BR>");
        Response.Write ("Print date: " + DateTime.Now.ToShortDateString());
        Response.Write("<BR>");
        Response.Write("<BR>");
        
        foreach (DataGrid Grid in mDataGridList)
        {
          Grid.RenderControl(lHtmlTextWriter);
        }
        Response.Write(lStringWriter.ToString());
		    WriteHtmlFoot();
      }
      catch(Exception)
      {
        Response.Write("Error while exporting to excel.");
      }

      Response.End();
    }

		/// <summary>
		/// Export data to an excel file. 
		/// </summary>
		/// <param name="mHtmlComponent">HTMLGeneric Control containing the data</param>
		/// <param name="mHasContent">if the report returns data or not</param>
		protected void ExportToExcel(HtmlControl mHtmlComponent, bool mHasContent)
		{
			if (mHasContent)
			{
				Response.Clear();
				Response.Buffer= false;
				Response.ContentType = "application/vnd.ms-excel";
				Response.Charset = "";
				this.EnableViewState = false;

				try
				{
					WriteHtmlHeader();          					
          System.IO.StringWriter lStringWriter = new System.IO.StringWriter();
          System.Web.UI.HtmlTextWriter lHtmlTextWriter = new System.Web.UI.HtmlTextWriter(lStringWriter);
					mHtmlComponent.RenderControl(lHtmlTextWriter);
				
					Response.Write(lStringWriter.ToString());
					WriteHtmlFoot();
				}
				catch(Exception)
				{
					Response.Write("Error while exporting to excel.");
				}

				Response.End();
			}
			else
			{
				Response.Write("<script>alert('" + FATCATConstants.DEFAULT_NO_RESULTS_MESSAGE + "');</script>");
				//Prevents open a new page in the history every time the alert is fired.
				//Thus, when an alert is fired, it backs to the calling page. 
				Response.Write("<script>history.go(-1);</script>");
				return;
			}
		}

		/// <summary>
		/// Export data to a word file. 
		/// </summary>
		/// <param name="mHtmlComponent">HTMLGeneric Control containing the data</param>
		/// <param name="mHasContent">if the report returns data or not</param>
		protected void ExportToWord(HtmlGenericControl mHtmlComponent, bool mHasContent)
		{
			if (mHasContent)
			{
				Response.Clear();
				Response.Buffer= false;
				Response.ContentType = "application/msword";
				Response.Charset = "";
				this.EnableViewState = false;

				try
				{
				  WriteHtmlHeader();										
          System.IO.StringWriter lStringWriter = new System.IO.StringWriter();
          System.Web.UI.HtmlTextWriter lHtmlTextWriter = new System.Web.UI.HtmlTextWriter(lStringWriter);
					mHtmlComponent.RenderControl(lHtmlTextWriter);
				
					Response.Write(lStringWriter.ToString());
          WriteHtmlFoot();
				}
				catch(Exception)
				{
					Response.Write("Error while exporting to word.");
				}

				Response.End();
			}
			else
			{
				Response.Write("<script>alert('" + FATCATConstants.DEFAULT_NO_RESULTS_MESSAGE + "');</script>");
				//Prevents open a new page in the history every time the alert is fired.
				//Thus, when an alert is fired, it backs to the calling page. 
				Response.Write("<script>history.go(-1);</script>");
				return;
			}
		}

    /// <summary>
    /// Writes the HTML header
    /// </summary>
    void WriteHtmlHeader()
    {
      Response.Write("<html>\n");
      Response.Write("<style>\n <!--");
      System.IO.StreamReader lStreamReader = new System.IO.StreamReader(Server.MapPath("styles/style.css"));
      Response.Write(lStreamReader.ReadToEnd());
      lStreamReader.Close();
      Response.Write("\n //--> \n </style>");
      Response.Write("<body>\n");                              
    }

    /// <summary>
    /// Writes the HTML foot
    /// </summary>
    void WriteHtmlFoot()
    {
      Response.Write("\n</body>");
      Response.Write("\n</html>");      
    }

    #region Web Form Designer generated code
    override protected void OnInit(EventArgs e)
    {
      //
      // CODEGEN: This call is required by the ASP.NET Web Form Designer.
      //
      InitializeComponent();
      base.OnInit(e);
    }
		
    /// <summary>
    /// Required method for Designer support - do not modify
    /// the contents of this method with the code editor.
    /// </summary>
    private void InitializeComponent()
    {    
    }
    #endregion
  }
}
