using System;
using System.Management.Instrumentation;
using System.Management;

namespace ManagedApp
{
	
	/// <summary>Tipos de evento para simulao</summary>
	public enum EventType
	{
		ServerStarted = 0,
		ServerStopped,
		ClientConnected,
		ClientDisconnected
	}

	/// <summary>Tipos de mensagem para simulao</summary>
	public enum MessageType
	{
		Error = 0,
		Warning,
		Information
	}

	/// <summary>
	/// Classe responsvel por manipular evento e mensagens
	/// no repositrio do WMI
	/// </summary>
	public class ProviderHandler
	{
		/// <summary>Publica a mensagem no repositrio</summary>
		/// <param name="_udtMessage">Mensagem a ser publicada pela aplicao</param>
		/// <returns>Indicativo de sucesso da operao</returns>
		public static bool PublishMessage(SyncPerformance _udtMessage)
		{
			try
			{
				// publica menssagem no repositrio WMI
				Instrumentation.Publish(_udtMessage);
			}
			catch (ManagementException)
			{
				// apenas retorna indicativo de erro
				return false;
			}

			return true;
		}

		/// <summary>Retira a mensagem do repositrio</summary>
		/// <param name="_udtMessage">Mensagem a ser removida</param>
		public static void RevokeMessage(SyncPerformance _udtMessage)
		{
			Instrumentation.Revoke(_udtMessage);
		}

		/// <summary>Gera um evento da aplicao</summary>
		public static bool FireEvent(EventDetails _udtEvent)
		{
			try
			{
				_udtEvent.Fire();
			}
			catch (ManagementException)
			{
				// apenas retorna indicativo de erro
				return false;
			}

			return true;
		}
	}
}
