using System;
using System.Management;
using System.Management.Instrumentation;
using System.Runtime.InteropServices;

namespace ManagedApp
{
	/// <summary>
	/// Summary description for SyncPerformanceHandler.
	/// </summary>
	public class SyncPerformanceHandler
	{
		//Varivel do tipo exposto via WMI
		private SyncPerformance devObj;
		
		private DateTime begin;
		private DateTime end;

		long endTime = 0;
		long startTime = 0;

		/// <summary>
		/// Imports the <code>QueryPerformanceFrequency</code> method into the class. The method is used to measure the current
		/// tickcount of the system.
		/// </summary>
		/// <param name="ticks">current tick count</param>
		[DllImport("Kernel32.dll")]
		public static extern void QueryPerformanceCounter(ref long ticks);

		public SyncPerformanceHandler(int deviceId)
		{
            devObj = new SyncPerformance();
			devObj.DevId = deviceId;
		}

		public void PublishPerformance()
		{
				// Publica menssagem no repositrio WMI
				Instrumentation.Publish(devObj);
		}

		public void BeginSync()
		{
			// measure starting time
			QueryPerformanceCounter(ref startTime);
			
			// Guarda a hora de inicio (em milisegundos) no objeto a ser publicado
			begin = DateTime.Now;
			devObj.SyncBeginTime = begin.ToLongTimeString();
		}

		public long EndSync()
		{
			//measure starting time
			QueryPerformanceCounter(ref endTime);

			// Guarda a hora de fim (em milisegundos) no objeto a ser publicado
			end = DateTime.Now;
			devObj.SyncEndTime = end.ToLongTimeString();
			
            //Subtrai hora de inicio da hora de fim
			TimeSpan time = end.Subtract(begin);
			
			// Guarda o tempo (em milisegundos) no objeto a ser publicado
			devObj.SpentTime = (long)time.TotalMilliseconds;
			
			return endTime - startTime;
		}
	}
}
